@@ -340,7 +340,7 @@ class VCFReader (object):
                         if v.sampleinfo['GQ'][samplekey] == '.':
                             quality_for_sample = 0
                         else:
-                            quality_for_sample = int(v.sampleinfo['DP'][samplekey])
+                            quality_for_sample = int(v.sampleinfo['GQ'][samplekey])
                         if quality_for_sample < h_filters[samplekey]['GQ']:
                             break                
                 else:
