@@ -584,7 +584,7 @@ SnapCLParser.add_argument("-S", "--selectivity", type = int, default = argparse.
 SnapCLParser.add_argument("-C", "--clipping", metavar = '++|+-|-+|--', default = argparse.SUPPRESS, help = 'specify a combination of two + or - symbols to indicate whether to clip low-quality bases from the front and back of reads respectively; default: back only (-C-+)')
 SnapCLParser.add_argument("-M", "--mmatch-notation", dest = 'mmatch_notation', action = 'store_true', default = argparse.SUPPRESS, help = 'indicates that CIGAR strings in the generated SAM file should use M (alignment match) rather than = and X (sequence (mis-)match)')
 SnapCLParser.add_argument("-G", "--gap-penalty", dest = 'gap_penalty', metavar = 'PENALTY', type = int, default = argparse.SUPPRESS, help = 'specify a gap penalty to use when generating CIGAR strings')
-SnapCLParser.add_argument("-s", "--spacing", nargs = 2, metavar = ('MIN','MAX'), default = argparse.SUPPRESS, help = 'min and max spacing to allow between paired ends (default: 100 1000)')
+SnapCLParser.add_argument("-s", "--spacing", nargs = 2, metavar = ('MIN','MAX'), default = [100, 10000], help = 'min and max spacing to allow between paired ends (default: 100 10000)')
 SnapCLParser.add_argument('--max-mate-overlap', '--mmo', dest = 'max_mate_overlap', metavar = 'FRACTION', type = float, default = argparse.SUPPRESS, help = 'for paired-end reads only retain reads with maximally this fraction of their length overlap with their mate; default: 0 (no overlap allowed)')
 SnapCLParser.add_argument('-q', '--quiet', action = 'store_true', default = False, help = 'suppress original messages from SNAP')
 SnapCLParser.add_argument('-v', '--verbose', action = 'store_true', default = False, help = 'verbose output (independent of SNAP)')
