@@ -1,4 +1,4 @@
-import os
+import os.path
 import shutil
 import random
 from .config import tmpfiles_path
@@ -15,6 +15,7 @@ def tmp_hardlink (ifile, prefix, suffix, fallback = 'symbolic'):
     if fallback not in supported_fallbacks:
         raise ValueError ('Unsupported fallback behavior. Only {0} accepted'.format(supported_fallbacks))
     hard_link = unique_tmpfile_name(prefix, suffix)
+    ifile = os.path.abspath(ifile) # an abspath is required just in case we need to soft-link
     try:
         try:
             os.link(ifile, hard_link)
