@@ -203,7 +203,8 @@ def snpeff_effects (vcf_entry):
                 raise
             eff_details = [d.split(':')[-1] for d in details.split('|')]
             l = len(eff_details)
-            assert 11 <= l <= 13, 'Mal-formatted EFF entry in vcf INFO field: {0}'.format(effect)
+            if not 11 <= l <= 13:
+                raise RuntimeError('Mal-formatted EFF entry in vcf INFO field: {0}'.format(effect))
             if l < 13: #no errors, no warnings
                 for i in range(13-l):
                     eff_details.append(None)
@@ -220,14 +221,12 @@ def snpeff (genome, inputfile = None, outputfile = None, memory = None, verbose
     inputfile (required): path to the input VCF file
     genome (required): the reference genome version;
     reference genome file must be at data/genomes/genome_version.fa.gz
-    relative to config.snpEff_path
+    relative to config.snpeff_path
     outputfile: path to outputfile;
     default: cwd/output.vcf
     stats: write an overview of the results to summary-file
                   (-stats, default: None)
     memory: GB of memory used (-Xmx<i>g, default: i = 2)
-    threads: use multiple threads (-t, default: None (off))
-    !warning: using multiple threads disables generating a summary file
     chr: prepend 'chr' to chromosome names if True, e.g., 'chr7' instead of '7'
     (-chr, default: False)
     minC: filter out sequence changes with coverage lower than min_cov
@@ -244,11 +243,15 @@ def snpeff (genome, inputfile = None, outputfile = None, memory = None, verbose
         (-ud, default: None)
     v: show messages and errors if True (-v, default: False)
     settings currently not modifiable through the interface:
-    -o vcf: output format is vcf; on by default."""
+    -o vcf: output format is vcf
+    -t (multithreading) is switched off"""
 
-    assert is_installed_snpeff_genome(genome), '{0} is not the name of an installed SnpEff genome.'.format(genome)
+    if not is_installed_snpeff_genome(genome):
+        raise ValueError(
+            '{0} is not the name of an installed SnpEff genome.'.format(genome))
     #adjust the memory parameter
     memory = '-Xmx{0}g'.format(memory or config.max_memory)
+     
     if not optionals.get('stats'):
         optionals['noStats'] = True
         
@@ -258,7 +261,6 @@ def snpeff (genome, inputfile = None, outputfile = None, memory = None, verbose
                     'ud':'-ud'}
 
     bool_table = {'chr':'-chr chr',
-                  'threads':'-t',
                   'no_downstream':'-no-downstream',
                   'no_upstream':'-no-upstream',
                   'no_intron':'-no-intron',
@@ -294,7 +296,7 @@ def snpeff (genome, inputfile = None, outputfile = None, memory = None, verbose
     # and have to make sure we change it back afterwards
     cwd = os.getcwd()
     try:
-        os.chdir(config.snpEff_path)
+        os.chdir(config.snpeff_path)
         if outputfile:
             proc = subprocess.Popen(snpeff_call, shell = True, stdout = subprocess.PIPE, stderr = subprocess.PIPE)
             results, errors = (s.decode() for s in proc.communicate())
@@ -319,8 +321,10 @@ def snpeff (genome, inputfile = None, outputfile = None, memory = None, verbose
 
 
 def get_snpeff_config_file ():
-    config_file = os.path.join(os.path.expanduser(config.snpEff_path), 'snpEff.config')
-    assert os.path.isfile(config_file), 'Could not get snpEff config file. Check the snpEff_path variable in the MiModD configuration settings.'
+    config_file = os.path.join(os.path.expanduser(config.snpeff_path), 'snpEff.config')
+    if not os.path.isfile(config_file):
+        raise RuntimeError(
+            'Could not get snpEff config file. Check the snpeff_path variable in the MiModD configuration settings.')
     return config_file
 
 def get_snpeff_data_dir (config_file = None):
@@ -328,10 +332,12 @@ def get_snpeff_data_dir (config_file = None):
         config_file = get_snpeff_config_file()
     with open(config_file) as ifo:
         for line in ifo:
-            if line.startswith('data_dir'):
+            if line.startswith('data_dir') or line.startswith('data.dir'):
                 data_dir = line.split('=')[-1].strip()
-                data_dir = os.path.normpath(os.path.join(os.path.expanduser(config.snpEff_path), os.path.expanduser(data_dir)))
-                assert os.path.isdir(data_dir), 'Could not find snpEff data directory at location {0} specified in snpEff config file.'.format(data_dir)
+                data_dir = os.path.normpath(os.path.join(os.path.expanduser(config.snpeff_path), os.path.expanduser(data_dir)))
+                if not os.path.isdir(data_dir):
+                    raise RuntimeError(
+                        'Could not find snpEff data directory at location {0} specified in snpEff config file.'.format(data_dir))
                 return data_dir
         raise RuntimeError ('snpEff config file at {0} does not specify a data directory.'.format(config_file))
 
