@@ -6,7 +6,14 @@ INDEL_TYPE = 2
 
 def filter(ifile, ofile = None, samples = (), gt = (), dp = (), gq = (), type_filter = None, region_filter = None, v_filter = None):
     # parameter sanity checks
-    if len(samples) != len(gt) != len(dp) != len(gq):
+    sample_no = len(samples)
+    if gt == ():
+        gt = ('ANY',) * sample_no
+    if dp == ():
+        dp = (0,) * sample_no
+    if gq == ():
+        gq = (0,) * sample_no
+    if not all(len(param) == len(samples) for param in (gt, dp, gq)):
         raise ValueError('The number of samples must match the number of genotype filters.')
     # transform region_filter from a sequence of regions to a chromosome-based dictionary
     if region_filter:
